import React, { useState, useEffect } from 'react';
import { CircleCheck, X } from 'lucide-react';

const DeveloperAmenities = ({ onAmenitiesSelect, developerAmenities }) => {
  // Convert string to array if it's a string, otherwise use the input as-is
  const amenitiesArray = typeof developerAmenities === 'string' 
    ? developerAmenities.split(',').map(amenity => amenity.trim())
    : (developerAmenities || []);

  const [selectedAmenities, setSelectedAmenities] = useState([]);

  // Use effect to initialize selected amenities from prop
  useEffect(() => {
    if (amenitiesArray.length > 0) {
      setSelectedAmenities(amenitiesArray);
    }
  }, [developerAmenities]);

  const handleAmenityToggle = (amenity) => {
    setSelectedAmenities(prev =>
      prev.includes(amenity)
        ? prev.filter(item => item !== amenity)
        : [...prev, amenity]
    );

    // Optional: Callback to parent component if needed
    if (onAmenitiesSelect) {
      onAmenitiesSelect(
        selectedAmenities.includes(amenity)
          ? selectedAmenities.filter(item => item !== amenity)
          : [...selectedAmenities, amenity]
      );
    }
  };

  // If no amenities, show a message
  if (amenitiesArray.length === 0 || amenitiesArray[0] === 'No amenities available') {
    return (
      <div className='bg-white rounded-xl shadow-lg py-4 flex flex-col gap-4'>
        <p className='px-4 sm:px-6 font-semibold text-base sm:text-lg text-gray-500'>
          No amenities available
        </p>
      </div>
    );
  }

  return (
    <div className='bg-white rounded-xl shadow-lg py-4 flex flex-col gap-4'>
      <p className='px-4 sm:px-6 font-semibold text-base sm:text-lg'>
        Amenities
      </p>
      <hr className='border-t-1 border-gray-200 mx-4 sm:mx-6' />
      <div className='px-4 sm:px-6'>
        <p className='font-semibold text-sm sm:text-base mb-3'>
          Developer Amenities
        </p>
        <div className='grid grid-cols-2 sm:grid-cols-3 lg:grid-cols-5 gap-3'>
          {amenitiesArray.map((amenity) => (
            <button
              key={amenity}
              onClick={() => handleAmenityToggle(amenity)}
              className={`
                flex items-center justify-between
                px-3 py-2
                border rounded-lg
                transition-all duration-200
                ${selectedAmenities.includes(amenity)
                  ? 'bg-green-100 border-green-300 text-green-800'
                  : 'bg-gray-100 border-gray-300 text-gray-800'}
              `}
            >
              <span className='text-xs sm:text-sm capitalize'>{amenity}</span>
              {selectedAmenities.includes(amenity) ? (
                <CircleCheck className='w-4 h-4 text-green-600' />
              ) : (
                <X className='w-4 h-4 text-gray-400' />
              )}
            </button>
          ))}
        </div>
      </div>
    </div>
  );
};

export default DeveloperAmenities;